@@ -81,11 +81,7 @@ void FileOpsContextManagerItem::updateServiceList()
         }
     }
 
-#if KIO_VERSION >= QT_VERSION_CHECK(5, 83, 0)
     mServiceList = KFileItemActions::associatedApplications(mimeTypes);
-#else
-    mServiceList = KFileItemActions::associatedApplications(mimeTypes, QString());
-#endif
 }
 
 QMimeData *FileOpsContextManagerItem::selectionMimeData()
@@ -106,7 +102,7 @@ QUrl FileOpsContextManagerItem::pasteTargetUrl() const
 {
     // If only one folder is selected, paste inside it, otherwise paste in
     // current
-    KFileItemList list = contextManager()->selectedFileItemList();
+    const KFileItemList list = contextManager()->selectedFileItemList();
     if (list.count() == 1 && list.first().isDir()) {
         return list.first().url();
     } else {
@@ -116,7 +112,7 @@ QUrl FileOpsContextManagerItem::pasteTargetUrl() const
 
 static QAction *createSeparator(QObject *parent)
 {
-    auto *action = new QAction(parent);
+    auto action = new QAction(parent);
     action->setSeparator(true);
     return action;
 }
@@ -139,8 +135,8 @@ FileOpsContextManagerItem::FileOpsContextManagerItem(ContextManager *manager,
     connect(contextManager(), &ContextManager::selectionChanged, this, &FileOpsContextManagerItem::updateActions);
     connect(contextManager(), &ContextManager::currentDirUrlChanged, this, &FileOpsContextManagerItem::updateActions);
 
-    auto *file = new KActionCategory(i18nc("@title actions category", "File"), actionCollection);
-    auto *edit = new KActionCategory(i18nc("@title actions category", "Edit"), actionCollection);
+    auto file = new KActionCategory(i18nc("@title actions category", "File"), actionCollection);
+    auto edit = new KActionCategory(i18nc("@title actions category", "Edit"), actionCollection);
 
     mCutAction = edit->addAction(KStandardAction::Cut, this, SLOT(cut()));
     mCopyAction = edit->addAction(KStandardAction::Copy, this, SLOT(copy()));
@@ -188,7 +184,7 @@ FileOpsContextManagerItem::FileOpsContextManagerItem(ContextManager *manager,
 
     mOpenWithAction = file->addAction(QStringLiteral("file_open_with"));
     mOpenWithAction->setText(i18n("Open With"));
-    auto *menu = new QMenu;
+    auto menu = new QMenu;
     mOpenWithAction->setMenu(menu);
     connect(menu, &QMenu::aboutToShow, this, &FileOpsContextManagerItem::populateOpenMenu);
     connect(menu, &QMenu::triggered, this, &FileOpsContextManagerItem::openWith);
@@ -275,11 +271,11 @@ void FileOpsContextManagerItem::updateSideBarContent()
 
 void FileOpsContextManagerItem::showProperties()
 {
-    KFileItemList list = contextManager()->selectedFileItemList();
-    if (list.count() > 0) {
+    const KFileItemList list = contextManager()->selectedFileItemList();
+    if (!list.isEmpty()) {
         KPropertiesDialog::showDialog(list, mGroup);
     } else {
-        QUrl url = contextManager()->currentDirUrl();
+        const QUrl url = contextManager()->currentDirUrl();
         KPropertiesDialog::showDialog(url, mGroup);
     }
 }
@@ -349,7 +345,7 @@ void FileOpsContextManagerItem::rename()
 
 void FileOpsContextManagerItem::createFolder()
 {
-    QUrl url = contextManager()->currentDirUrl();
+    const QUrl url = contextManager()->currentDirUrl();
     mNewFileMenu->setParentWidget(mGroup);
     mNewFileMenu->setPopupFiles(QList<QUrl>() << url);
     mNewFileMenu->createDirectory();
@@ -380,7 +376,7 @@ void FileOpsContextManagerItem::openWith(QAction *action)
 {
     Q_ASSERT(action);
     KService::Ptr service;
-    QList<QUrl> list = urlList();
+    const QList<QUrl> list = urlList();
 
     bool ok;
     int idx = action->data().toInt(&ok);
@@ -389,7 +385,7 @@ void FileOpsContextManagerItem::openWith(QAction *action)
         service = mServiceList.at(idx);
     }
     // If service is null, ApplicationLauncherJob will invoke the open-with dialog
-    auto *job = new KIO::ApplicationLauncherJob(service);
+    auto job = new KIO::ApplicationLauncherJob(service);
     job->setUrls(list);
     job->setUiDelegate(new KIO::JobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, mGroup));
     job->start();
