@@ -88,10 +88,6 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 #include "imageopscontextmanageritem.h"
 #include "infocontextmanageritem.h"
 #include "viewmainpage.h"
-#ifdef KIPI_FOUND
-#include "kipiexportaction.h"
-#include "kipiinterface.h"
-#endif
 #ifndef GWENVIEW_SEMANTICINFO_BACKEND_NONE
 #include "semanticinfocontextmanageritem.h"
 #endif
@@ -171,64 +167,58 @@ Layout of the main window looks like this:
 
 */
 struct MainWindow::Private {
-    GvCore *mGvCore;
-    MainWindow *q;
-    QSplitter *mCentralSplitter;
-    QWidget *mContentWidget;
-    ViewMainPage *mViewMainPage;
-    KUrlNavigator *mUrlNavigator;
-    ThumbnailView *mThumbnailView;
-    ThumbnailView *mActiveThumbnailView;
-    DocumentInfoProvider *mDocumentInfoProvider;
-    ThumbnailViewHelper *mThumbnailViewHelper;
+    GvCore *mGvCore = nullptr;
+    MainWindow *q = nullptr;
+    QSplitter *mCentralSplitter = nullptr;
+    QWidget *mContentWidget = nullptr;
+    ViewMainPage *mViewMainPage = nullptr;
+    KUrlNavigator *mUrlNavigator = nullptr;
+    ThumbnailView *mThumbnailView = nullptr;
+    ThumbnailView *mActiveThumbnailView = nullptr;
+    DocumentInfoProvider *mDocumentInfoProvider = nullptr;
+    ThumbnailViewHelper *mThumbnailViewHelper = nullptr;
     QPointer<ThumbnailProvider> mThumbnailProvider;
-    BrowseMainPage *mBrowseMainPage;
-    StartMainPage *mStartMainPage;
-    SideBar *mSideBar;
-    KMessageWidget *mSharedMessage;
-    QStackedWidget *mViewStackedWidget;
-    FullScreenContent *mFullScreenContent;
-    SaveBar *mSaveBar;
+    BrowseMainPage *mBrowseMainPage = nullptr;
+    StartMainPage *mStartMainPage = nullptr;
+    SideBar *mSideBar = nullptr;
+    KMessageWidget *mSharedMessage = nullptr;
+    QStackedWidget *mViewStackedWidget = nullptr;
+    FullScreenContent *mFullScreenContent = nullptr;
+    SaveBar *mSaveBar = nullptr;
     bool mStartSlideShowWhenDirListerCompleted;
-    SlideShow *mSlideShow;
+    SlideShow *mSlideShow = nullptr;
 #ifdef HAVE_QTDBUS
-    Mpris2Service *mMpris2Service;
+    Mpris2Service *mMpris2Service = nullptr;
 #endif
-    Preloader *mPreloader;
+    Preloader *mPreloader = nullptr;
     bool mPreloadDirectionIsForward;
-#ifdef KIPI_FOUND
-    KIPIInterface *mKIPIInterface;
-#endif
 
-    QActionGroup *mViewModeActionGroup;
-    KRecentFilesAction *mFileOpenRecentAction;
-    QAction *mBrowseAction;
-    QAction *mViewAction;
-    QAction *mGoUpAction;
-    QAction *mGoToPreviousAction;
-    QAction *mGoToNextAction;
-    QAction *mGoToFirstAction;
-    QAction *mGoToLastAction;
-    KToggleAction *mToggleSideBarAction;
-    KToggleAction *mToggleOperationsSideBarAction;
-    QAction *mFullScreenAction;
-    QAction *mToggleSlideShowAction;
-    KToggleAction *mShowMenuBarAction;
-    KToggleAction *mShowStatusBarAction;
-    QPointer<HudButtonBox> hudButtonBox;
+    QActionGroup *mViewModeActionGroup = nullptr;
+    KRecentFilesAction *mFileOpenRecentAction = nullptr;
+    QAction *mBrowseAction = nullptr;
+    QAction *mViewAction = nullptr;
+    QAction *mGoUpAction = nullptr;
+    QAction *mGoToPreviousAction = nullptr;
+    QAction *mGoToNextAction = nullptr;
+    QAction *mGoToFirstAction = nullptr;
+    QAction *mGoToLastAction = nullptr;
+    KToggleAction *mToggleSideBarAction = nullptr;
+    KToggleAction *mToggleOperationsSideBarAction = nullptr;
+    QAction *mFullScreenAction = nullptr;
+    QAction *mToggleSlideShowAction = nullptr;
+    KToggleAction *mShowMenuBarAction = nullptr;
+    KToggleAction *mShowStatusBarAction = nullptr;
+    QPointer<HudButtonBox> hudButtonBox = nullptr;
 #ifdef KF5Purpose_FOUND
-    Purpose::Menu *mShareMenu;
-    KToolBarPopupAction *mShareAction;
+    Purpose::Menu *mShareMenu = nullptr;
+    KToolBarPopupAction *mShareAction = nullptr;
 #endif
-#ifdef KIPI_FOUND
-    KIPIExportAction *mKIPIExportAction;
-#endif
-    KHamburgerMenu *mHamburgerMenu;
+    KHamburgerMenu *mHamburgerMenu = nullptr;
 
-    SortedDirModel *mDirModel;
-    DocumentOnlyProxyModel *mThumbnailBarModel;
-    KLinkItemSelectionModel *mThumbnailBarSelectionModel;
-    ContextManager *mContextManager;
+    SortedDirModel *mDirModel = nullptr;
+    DocumentOnlyProxyModel *mThumbnailBarModel = nullptr;
+    KLinkItemSelectionModel *mThumbnailBarSelectionModel = nullptr;
+    ContextManager *mContextManager = nullptr;
 
     MainWindowState mStateBeforeFullScreen;
 
@@ -237,7 +227,7 @@ struct MainWindow::Private {
     MainPageId mCurrentMainPageId;
 
     QDateTime mFullScreenLeftAt;
-    KNotificationRestrictions *mNotificationRestrictions;
+    KNotificationRestrictions *mNotificationRestrictions = nullptr;
 
     void setupContextManager()
     {
@@ -266,7 +256,7 @@ struct MainWindow::Private {
         mSaveBar = new SaveBar(mContentWidget, q->actionCollection());
         connect(mContextManager, &ContextManager::currentUrlChanged, mSaveBar, &SaveBar::setCurrentUrl);
         mViewStackedWidget = new QStackedWidget(mContentWidget);
-        auto *layout = new QVBoxLayout(mContentWidget);
+        auto layout = new QVBoxLayout(mContentWidget);
         layout->addWidget(mSharedMessage);
         layout->addWidget(mSaveBar);
         layout->addWidget(mViewStackedWidget);
@@ -371,27 +361,28 @@ struct MainWindow::Private {
 
     void installDisabledActionShortcutMonitor(QAction *action, const char *slot)
     {
-        auto *monitor = new DisabledActionShortcutMonitor(action, q);
+        auto monitor = new DisabledActionShortcutMonitor(action, q);
         connect(monitor, SIGNAL(activated()), q, slot);
     }
 
     void setupActions()
     {
         KActionCollection *actionCollection = q->actionCollection();
-        auto *file = new KActionCategory(i18nc("@title actions category", "File"), actionCollection);
-        auto *view = new KActionCategory(i18nc("@title actions category - means actions changing smth in interface", "View"), actionCollection);
+        auto file = new KActionCategory(i18nc("@title actions category", "File"), actionCollection);
+        auto view = new KActionCategory(i18nc("@title actions category - means actions changing smth in interface", "View"), actionCollection);
 
         file->addAction(KStandardAction::Save, q, SLOT(saveCurrent()));
         file->addAction(KStandardAction::SaveAs, q, SLOT(saveCurrentAs()));
         file->addAction(KStandardAction::Open, q, SLOT(openFile()));
         mFileOpenRecentAction = KStandardAction::openRecent(q, SLOT(openUrl(QUrl)), q);
         connect(mFileOpenRecentAction, &KRecentFilesAction::recentListCleared, mGvCore, &GvCore::clearRecentFilesAndFolders);
-        auto *clearAction = mFileOpenRecentAction->menu()->findChild<QAction *>("clear_action");
+        auto clearAction = mFileOpenRecentAction->menu()->findChild<QAction *>("clear_action");
         if (clearAction) {
             clearAction->setText(i18nc("@action Open Recent menu", "Clear List"));
         }
         file->addAction("file_open_recent", mFileOpenRecentAction);
         file->addAction(KStandardAction::Print, q, SLOT(print()));
+        file->addAction(KStandardAction::PrintPreview, q, SLOT(printPreview()));
         file->addAction(KStandardAction::Quit, qApp, SLOT(closeAllWindows()));
 
         QAction *action = file->addAction("reload", q, SLOT(reload()));
@@ -437,16 +428,18 @@ struct MainWindow::Private {
 
         mGoToPreviousAction = view->addAction("go_previous", q, SLOT(goToPrevious()));
         mGoToPreviousAction->setPriority(QAction::LowPriority);
-        mGoToPreviousAction->setIcon(QIcon::fromTheme("go-previous-view"));
+        mGoToPreviousAction->setIcon(QIcon::fromTheme(QGuiApplication::layoutDirection() == Qt::LeftToRight ? "go-previous" : "go-previous-symbolic-rtl"));
         mGoToPreviousAction->setText(i18nc("@action Go to previous image", "Previous"));
         mGoToPreviousAction->setToolTip(i18nc("@info:tooltip", "Go to previous image"));
+        actionCollection->setDefaultShortcuts(mGoToPreviousAction, {QKeySequence(Qt::Key_Left)});
         installDisabledActionShortcutMonitor(mGoToPreviousAction, SLOT(showFirstDocumentReached()));
 
         mGoToNextAction = view->addAction("go_next", q, SLOT(goToNext()));
         mGoToNextAction->setPriority(QAction::LowPriority);
-        mGoToNextAction->setIcon(QIcon::fromTheme("go-next-view"));
+        mGoToNextAction->setIcon(QIcon::fromTheme(QGuiApplication::layoutDirection() == Qt::LeftToRight ? "go-next" : "go-next-symbolic-rtl"));
         mGoToNextAction->setText(i18nc("@action Go to next image", "Next"));
         mGoToNextAction->setToolTip(i18nc("@info:tooltip", "Go to next image"));
+        actionCollection->setDefaultShortcuts(mGoToNextAction, {QKeySequence(Qt::Key_Right)});
         installDisabledActionShortcutMonitor(mGoToNextAction, SLOT(showLastDocumentReached()));
 
         mGoToFirstAction = view->addAction("go_first", q, SLOT(goToFirst()));
@@ -512,10 +505,6 @@ struct MainWindow::Private {
 
         view->addAction(KStandardAction::ConfigureToolbars, q, SLOT(configureToolbars()));
 
-#ifdef KIPI_FOUND
-        mKIPIExportAction = new KIPIExportAction(q);
-#endif
-
 #ifdef KF5Purpose_FOUND
         mShareAction = new KToolBarPopupAction(QIcon::fromTheme("document-share"), i18nc("@action Share images", "Share"), q);
         mShareAction->setDelayed(false);
@@ -543,7 +532,7 @@ struct MainWindow::Private {
         });
 #endif
 
-        auto alignWithSideBarWidgetAction = new AlignWithSideBarWidgetAction();
+        auto alignWithSideBarWidgetAction = new AlignWithSideBarWidgetAction(q);
         alignWithSideBarWidgetAction->setSideBar(mSideBar);
         actionCollection->addAction("align_with_sidebar", alignWithSideBarWidgetAction);
 
@@ -562,12 +551,13 @@ struct MainWindow::Private {
     void updateHamburgerMenu()
     {
         KActionCollection *actionCollection = q->actionCollection();
-        auto *menu = new QMenu;
+        auto menu = new QMenu;
         menu->addAction(actionCollection->action(KStandardAction::name(KStandardAction::Open)));
         menu->addAction(actionCollection->action(KStandardAction::name(KStandardAction::OpenRecent)));
         menu->addAction(actionCollection->action(KStandardAction::name(KStandardAction::Save)));
         menu->addAction(actionCollection->action(KStandardAction::name(KStandardAction::SaveAs)));
         menu->addAction(actionCollection->action(KStandardAction::name(KStandardAction::Print)));
+        menu->addAction(actionCollection->action(KStandardAction::name(KStandardAction::PrintPreview)));
         menu->addSeparator();
         menu->addAction(actionCollection->action(KStandardAction::name(KStandardAction::Copy)));
         menu->addAction(actionCollection->action(QStringLiteral("file_trash")));
@@ -581,13 +571,7 @@ struct MainWindow::Private {
 #ifdef KF5Purpose_FOUND
         menu->addMenu(mShareMenu);
 #endif
-#ifdef KIPI_FOUND
-        QMenu *pluginsMenu = static_cast<QMenu *>(q->guiFactory()->container("plugins", q));
-        if (pluginsMenu) {
-            menu->addMenu(pluginsMenu);
-        }
-#endif
-        auto *configureMenu = new QMenu(i18nc("@title:menu submenu for actions that open configuration dialogs", "Configure"));
+        auto configureMenu = new QMenu(i18nc("@title:menu submenu for actions that open configuration dialogs", "Configure"));
         configureMenu->addAction(actionCollection->action(QStringLiteral("options_configure_keybinding")));
         configureMenu->addAction(actionCollection->action(QStringLiteral("options_configure_toolbars")));
         configureMenu->addAction(actionCollection->action(QStringLiteral("options_configure")));
@@ -602,7 +586,7 @@ struct MainWindow::Private {
         QUndoGroup *undoGroup = DocumentFactory::instance()->undoGroup();
         QAction *action;
         KActionCollection *actionCollection = q->actionCollection();
-        auto *edit = new KActionCategory(i18nc("@title actions category - means actions changing smth in interface", "Edit"), actionCollection);
+        auto edit = new KActionCategory(i18nc("@title actions category - means actions changing smth in interface", "Edit"), actionCollection);
 
         action = undoGroup->createRedoAction(actionCollection);
         action->setObjectName(KStandardAction::name(KStandardAction::Redo));
@@ -626,19 +610,19 @@ struct MainWindow::Private {
         KActionCollection *actionCollection = q->actionCollection();
 
         // Create context manager items
-        auto *folderViewItem = new FolderViewContextManagerItem(mContextManager);
+        auto folderViewItem = new FolderViewContextManagerItem(mContextManager);
         connect(folderViewItem, &FolderViewContextManagerItem::urlChanged, q, &MainWindow::folderViewUrlChanged);
 
-        auto *infoItem = new InfoContextManagerItem(mContextManager);
+        auto infoItem = new InfoContextManagerItem(mContextManager);
 
 #ifndef GWENVIEW_SEMANTICINFO_BACKEND_NONE
         SemanticInfoContextManagerItem *semanticInfoItem = nullptr;
         semanticInfoItem = new SemanticInfoContextManagerItem(mContextManager, actionCollection, mViewMainPage);
 #endif
 
-        auto *imageOpsItem = new ImageOpsContextManagerItem(mContextManager, q);
+        auto imageOpsItem = new ImageOpsContextManagerItem(mContextManager, q);
 
-        auto *fileOpsItem = new FileOpsContextManagerItem(mContextManager, mThumbnailView, actionCollection, q);
+        auto fileOpsItem = new FileOpsContextManagerItem(mContextManager, mThumbnailView, actionCollection, q);
 
         // Fill sidebar
         SideBarPage *page;
@@ -653,7 +637,7 @@ struct MainWindow::Private {
         page->addWidget(infoItem->widget());
 #ifndef GWENVIEW_SEMANTICINFO_BACKEND_NONE
         if (semanticInfoItem) {
-            auto *separator = new QFrame;
+            auto separator = new QFrame;
             separator->setFrameShape(QFrame::HLine);
             separator->setLineWidth(1);
             page->addWidget(separator);
@@ -665,7 +649,7 @@ struct MainWindow::Private {
         page = new SideBarPage(QIcon::fromTheme("document-edit"), i18n("Operations"));
         page->setObjectName(QLatin1String("operations"));
         page->addWidget(imageOpsItem->widget());
-        auto *separator = new QFrame;
+        auto separator = new QFrame;
         separator->setFrameShape(QFrame::HLine);
         separator->setLineWidth(1);
         page->addWidget(separator);
@@ -793,6 +777,7 @@ struct MainWindow::Private {
         actionCollection->action("file_save")->setEnabled(canSave && isModified);
         actionCollection->action("file_save_as")->setEnabled(canSave);
         actionCollection->action("file_print")->setEnabled(isRasterImage);
+        actionCollection->action("file_print_preview")->setEnabled(isRasterImage);
 
 #ifdef KF5Purpose_FOUND
         if (url.isEmpty()) {
@@ -919,6 +904,64 @@ struct MainWindow::Private {
             assignThumbnailProviderToThumbnailView(mStartMainPage->recentFoldersView());
         }
     }
+
+    enum class ShowPreview { Yes, No };
+    void print(ShowPreview showPreview)
+    {
+        if (!mContextManager->currentUrlIsRasterImage()) {
+            return;
+        }
+
+        Document::Ptr doc = DocumentFactory::instance()->load(mContextManager->currentUrl());
+        PrintHelper printHelper(q);
+        if (showPreview == ShowPreview::Yes) {
+            printHelper.printPreview(doc);
+        } else {
+            printHelper.print(doc);
+        }
+    }
+
+    /// Handles the clicking of links in help texts if the clicked url uses the "gwenview:" scheme.
+    class InternalUrlClickedHandler : public QObject
+    {
+    public:
+        InternalUrlClickedHandler(MainWindow *parent)
+            : QObject(parent)
+        {
+            Q_CHECK_PTR(parent);
+        }
+
+        inline bool eventFilter(QObject * /* watched */, QEvent *event) override
+        {
+            if (event->type() != QEvent::WhatsThisClicked) {
+                return false;
+            }
+            const QString linkAddress = static_cast<QWhatsThisClickedEvent *>(event)->href();
+            if (!linkAddress.startsWith(QStringLiteral("gwenview:"))) {
+                // This eventFilter only handles our internal "gwenview" scheme. Everything else is handled by KXmlGui::KToolTipHelper.
+                return false;
+            }
+            event->accept();
+            auto linkPathList = linkAddress.split(QLatin1Char('/'));
+            linkPathList.removeFirst(); // remove "gwenview:/"
+            Q_ASSERT(!linkPathList.isEmpty());
+            Q_ASSERT_X(linkPathList.constFirst() == QStringLiteral("config"), "link resolver", "Handling of this URL is not yet implemented");
+            linkPathList.removeFirst(); // remove "config/"
+            auto mainWindow = static_cast<MainWindow *>(parent());
+            if (linkPathList.isEmpty()) {
+                mainWindow->showConfigDialog();
+            } else if (linkPathList.constFirst() == QStringLiteral("general")) {
+                mainWindow->showConfigDialog(0); // "0" should open General.
+            } else if (linkPathList.constFirst() == QStringLiteral("imageview")) {
+                mainWindow->showConfigDialog(1); // "1" should open Image View.
+            } else if (linkPathList.constFirst() == QStringLiteral("advanced")) {
+                mainWindow->showConfigDialog(2); // "2" should open Advanced.
+            } else {
+                Q_ASSERT_X(false, "config link resolver", "Handling of this config URL is not yet implemented");
+            }
+            return true;
+        }
+    };
 };
 
 MainWindow::MainWindow()
@@ -956,27 +999,18 @@ MainWindow::MainWindow()
         new Mpris2Service(d->mSlideShow, d->mContextManager, d->mToggleSlideShowAction, d->mFullScreenAction, d->mGoToPreviousAction, d->mGoToNextAction, this);
 #endif
 
-    auto *ratingMenu = static_cast<QMenu *>(guiFactory()->container("rating", this));
+    auto ratingMenu = static_cast<QMenu *>(guiFactory()->container("rating", this));
     ratingMenu->setIcon(QIcon::fromTheme(QStringLiteral("rating-unrated")));
 #ifdef GWENVIEW_SEMANTICINFO_BACKEND_NONE
     if (ratingMenu) {
         ratingMenu->menuAction()->setVisible(false);
     }
 #endif
-
-#ifdef KIPI_FOUND
-    d->mKIPIInterface = new KIPIInterface(this);
-    d->mKIPIExportAction->setKIPIInterface(d->mKIPIInterface);
-#else
-    auto *pluginsMenu = static_cast<QMenu *>(guiFactory()->container("plugins", this));
-    if (pluginsMenu) {
-        pluginsMenu->menuAction()->setVisible(false);
-    }
-#endif
     setAutoSaveSettings();
 #ifdef Q_OS_OSX
     qApp->installEventFilter(this);
 #endif
+    qApp->installEventFilter(new Private::InternalUrlClickedHandler(this));
 }
 
 MainWindow::~MainWindow()
@@ -1036,7 +1070,7 @@ void MainWindow::setInitialUrl(const QUrl &_url)
     message << dirUrl.toString();
 
     QDBusPendingCall call = QDBusConnection::sessionBus().asyncCall(message);
-    auto *watcher = new QDBusPendingCallWatcher(call, this);
+    auto watcher = new QDBusPendingCallWatcher(call, this);
 
     connect(watcher, &QDBusPendingCallWatcher::finished, this, [this](QDBusPendingCallWatcher *call) {
         QDBusPendingReply<QString, QString> reply = *call;
@@ -1410,6 +1444,7 @@ void MainWindow::goToPrevious()
     const QModelIndex currentIndex = d->mContextManager->selectionModel()->currentIndex();
     QModelIndex previousIndex = d->mDirModel->index(currentIndex.row(), 0);
 
+    constexpr QFlags<MimeTypeUtils::Kind> allowedKinds = MimeTypeUtils::KIND_RASTER_IMAGE | MimeTypeUtils::KIND_SVG_IMAGE | MimeTypeUtils::KIND_VIDEO;
     KFileItem fileItem;
 
     // Besides images also folders and archives are listed as well,
@@ -1417,7 +1452,7 @@ void MainWindow::goToPrevious()
     do {
         previousIndex = d->mDirModel->index(previousIndex.row() - 1, 0);
         fileItem = previousIndex.data(KDirModel::FileItemRole).value<KFileItem>();
-    } while (previousIndex.isValid() && !MimeTypeUtils::imageMimeTypes().contains(fileItem.currentMimeType().name()));
+    } while (previousIndex.isValid() && !(allowedKinds & MimeTypeUtils::fileItemKind(fileItem)));
 
     if (!previousIndex.isValid()
         && (GwenviewConfig::navigationEndNotification() == SlideShow::NeverWarn
@@ -1436,6 +1471,7 @@ void MainWindow::goToNext()
     const QModelIndex currentIndex = d->mContextManager->selectionModel()->currentIndex();
     QModelIndex nextIndex = d->mDirModel->index(currentIndex.row(), 0);
 
+    constexpr QFlags<MimeTypeUtils::Kind> allowedKinds = MimeTypeUtils::KIND_RASTER_IMAGE | MimeTypeUtils::KIND_SVG_IMAGE | MimeTypeUtils::KIND_VIDEO;
     KFileItem fileItem;
 
     // Besides images also folders and archives are listed as well,
@@ -1443,7 +1479,7 @@ void MainWindow::goToNext()
     do {
         nextIndex = d->mDirModel->index(nextIndex.row() + 1, 0);
         fileItem = nextIndex.data(KDirModel::FileItemRole).value<KFileItem>();
-    } while (nextIndex.isValid() && !MimeTypeUtils::imageMimeTypes().contains(fileItem.currentMimeType().name()));
+    } while (nextIndex.isValid() && !(allowedKinds & MimeTypeUtils::fileItemKind(fileItem)));
 
     if (!nextIndex.isValid()
         && (GwenviewConfig::navigationEndNotification() == SlideShow::NeverWarn
@@ -1587,7 +1623,7 @@ void MainWindow::openFile()
 {
     const QUrl dirUrl = d->mContextManager->currentDirUrl();
 
-    auto *dialog = new QFileDialog(this);
+    auto dialog = new QFileDialog(this);
     dialog->setAttribute(Qt::WA_DeleteOnClose);
     dialog->setModal(true);
     dialog->setDirectoryUrl(dirUrl);
@@ -1689,25 +1725,22 @@ bool MainWindow::queryClose()
     }
 }
 
-void MainWindow::showConfigDialog()
+void MainWindow::showConfigDialog(int page)
 {
     // Save first so changes like thumbnail zoom level are not lost when reloading config
     saveConfig();
 
-    auto *dialog = new ConfigDialog(this);
+    auto dialog = new ConfigDialog(this);
     dialog->setAttribute(Qt::WA_DeleteOnClose);
     dialog->setModal(true);
     connect(dialog, &KConfigDialog::settingsChanged, this, &MainWindow::loadConfig);
+    dialog->setCurrentPage(page);
     dialog->show();
 }
 
 void MainWindow::configureShortcuts()
 {
-#if KXMLGUI_VERSION >= QT_VERSION_CHECK(5, 84, 0)
     guiFactory()->showConfigureShortcutsDialog();
-#else
-    guiFactory()->configureShortcuts();
-#endif
 }
 
 void MainWindow::toggleMenuBar()
@@ -1766,13 +1799,12 @@ void MainWindow::saveConfig()
 
 void MainWindow::print()
 {
-    if (!d->mContextManager->currentUrlIsRasterImage()) {
-        return;
-    }
+    d->print(Private::ShowPreview::No);
+}
 
-    Document::Ptr doc = DocumentFactory::instance()->load(d->mContextManager->currentUrl());
-    PrintHelper printHelper(this);
-    printHelper.print(doc);
+void MainWindow::printPreview()
+{
+    d->print(Private::ShowPreview::Yes);
 }
 
 void MainWindow::preloadNextUrl()
