@@ -24,7 +24,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 #include <QApplication>
 #include <QCheckBox>
 #include <QComboBox>
-#include <QDesktopWidget>
+//#include <QDesktopWidget>
 #include <QDialogButtonBox>
 #include <QFontDatabase>
 #include <QHBoxLayout>
@@ -64,18 +64,18 @@ static QSize ratio(const QSize &size)
 struct CropWidgetPrivate : public QWidget {
     CropWidget *q;
     QList<QWidget *> mAdvancedWidgets;
-    QWidget *mPreserveAspectRatioWidget;
-    QCheckBox *advancedCheckBox;
-    QComboBox *ratioComboBox;
-    QSpinBox *widthSpinBox;
-    QSpinBox *heightSpinBox;
-    QSpinBox *leftSpinBox;
-    QSpinBox *topSpinBox;
-    QCheckBox *preserveAspectRatioCheckBox;
-    QDialogButtonBox *dialogButtonBox;
+    QWidget *mPreserveAspectRatioWidget = nullptr;
+    QCheckBox *advancedCheckBox = nullptr;
+    QComboBox *ratioComboBox = nullptr;
+    QSpinBox *widthSpinBox = nullptr;
+    QSpinBox *heightSpinBox = nullptr;
+    QSpinBox *leftSpinBox = nullptr;
+    QSpinBox *topSpinBox = nullptr;
+    QCheckBox *preserveAspectRatioCheckBox = nullptr;
+    QDialogButtonBox *dialogButtonBox = nullptr;
 
     Document::Ptr mDocument;
-    CropTool *mCropTool;
+    CropTool *mCropTool = nullptr;
     bool mUpdatingFromCropTool;
     int mCurrentImageComboBoxIndex;
     int mCropRatioComboBoxCurrentIndex;
@@ -144,7 +144,7 @@ struct CropWidgetPrivate : public QWidget {
     double cropRatio() const
     {
         if (q->advancedSettingsEnabled()) {
-            QSizeF size = chosenRatio();
+            const QSizeF size = chosenRatio();
             if (size.isEmpty()) {
                 return 0;
             }
@@ -152,7 +152,7 @@ struct CropWidgetPrivate : public QWidget {
         }
 
         if (q->preserveAspectRatio()) {
-            QSizeF size = ratio(mDocument->size());
+            const QSizeF size = ratio(mDocument->size());
             return size.height() / size.width();
         }
 
@@ -161,7 +161,7 @@ struct CropWidgetPrivate : public QWidget {
 
     void addRatioToComboBox(const QSizeF &size, const QString &label = QString())
     {
-        QString text = label.isEmpty() ? QStringLiteral("%1:%2").arg(size.width()).arg(size.height()) : label;
+        const QString text = label.isEmpty() ? QStringLiteral("%1:%2").arg(size.width()).arg(size.height()) : label;
         ratioComboBox->addItem(text, QVariant(size));
     }
 
@@ -191,7 +191,10 @@ struct CropWidgetPrivate : public QWidget {
         mCurrentImageComboBoxIndex = ratioComboBox->count() - 1; // We need to refer to this ratio later
 
         addRatioToComboBox(QSizeF(1, 1), i18n("Square"));
-        addRatioToComboBox(ratio(QGuiApplication::screenAt(QCursor::pos())->geometry().size()), i18n("This Screen"));
+        const QScreen *screen = QGuiApplication::screenAt(QCursor::pos());
+        if (screen) {
+            addRatioToComboBox(ratio(screen->geometry().size()), i18n("This Screen"));
+        }
         addSectionHeaderToComboBox(i18n("Landscape"));
 
         for (const QSizeF &size : qAsConst(ratioList)) {
@@ -210,7 +213,7 @@ struct CropWidgetPrivate : public QWidget {
         ratioComboBox->setMaxVisibleItems(ratioComboBox->count());
         ratioComboBox->clearEditText();
 
-        auto *edit = qobject_cast<QLineEdit *>(ratioComboBox->lineEdit());
+        auto edit = qobject_cast<QLineEdit *>(ratioComboBox->lineEdit());
         Q_ASSERT(edit);
         // Do not use i18n("%1:%2") because ':' should not be translated, it is
         // used to parse the ratio string.
@@ -229,13 +232,13 @@ struct CropWidgetPrivate : public QWidget {
 
     QRect cropRect() const
     {
-        QRect rect(leftSpinBox->value(), topSpinBox->value(), widthSpinBox->value(), heightSpinBox->value());
+        const QRect rect(leftSpinBox->value(), topSpinBox->value(), widthSpinBox->value(), heightSpinBox->value());
         return rect;
     }
 
     void initSpinBoxes()
     {
-        QSize size = mDocument->size();
+        const QSize size = mDocument->size();
         leftSpinBox->setMaximum(size.width());
         widthSpinBox->setMaximum(size.width());
         topSpinBox->setMaximum(size.height());
@@ -265,8 +268,8 @@ struct CropWidgetPrivate : public QWidget {
 
     QWidget *boxWidget(QWidget *parent = nullptr)
     {
-        auto *widget = new QWidget(parent);
-        auto *layout = new QHBoxLayout(widget);
+        auto widget = new QWidget(parent);
+        auto layout = new QHBoxLayout(widget);
         layout->setContentsMargins(0, 0, 0, 0);
         layout->setSpacing(2);
         return widget;
@@ -276,7 +279,7 @@ struct CropWidgetPrivate : public QWidget {
     {
         cropWidget->setObjectName(QStringLiteral("CropWidget"));
 
-        auto *flowLayout = new FlowLayout(cropWidget, 6, 0);
+        auto flowLayout = new FlowLayout(cropWidget, 6, 0);
         flowLayout->setObjectName(QStringLiteral("CropWidgetFlowLayout"));
         flowLayout->setAlignment(Qt::AlignCenter);
         flowLayout->setVerticalSpacing(6);
@@ -292,7 +295,7 @@ struct CropWidgetPrivate : public QWidget {
         // (2) Ratio combobox (Advanced settings)
         box = boxWidget(cropWidget);
         mAdvancedWidgets << box;
-        auto *label = new QLabel(i18nc("@label:listbox", "Aspect ratio:"), box);
+        auto label = new QLabel(i18nc("@label:listbox", "Aspect ratio:"), box);
         label->setContentsMargins(4, 4, 4, 4);
         box->layout()->addWidget(label);
         ratioComboBox = new QComboBox(box);
@@ -309,7 +312,7 @@ struct CropWidgetPrivate : public QWidget {
         label->setContentsMargins(4, 4, 4, 4);
         box->layout()->addWidget(label);
 
-        auto *innerLayout = new QHBoxLayout();
+        auto innerLayout = new QHBoxLayout();
         innerLayout->setSpacing(3);
 
         widthSpinBox = new QSpinBox(box);
