@@ -33,7 +33,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA
 namespace Gwenview
 {
 struct GraphicsWidgetFloaterPrivate {
-    QGraphicsWidget *mParent;
+    QGraphicsWidget *mParent = nullptr;
     QPointer<QGraphicsWidget> mChild;
     Qt::Alignment mAlignment;
 
