@@ -78,7 +78,7 @@ static KFileItem fileItemForIndex(const QModelIndex &index)
 {
     if (!index.isValid()) {
         LOG("Invalid index");
-        return KFileItem();
+        return {};
     }
     QVariant data = index.data(KDirModel::FileItemRole);
     return qvariant_cast<KFileItem>(data);
@@ -283,7 +283,7 @@ struct ThumbnailViewPrivate {
         }
         // Keep compiler happy
         Q_ASSERT(0);
-        return QPixmap();
+        return {};
     }
 };
 
@@ -588,7 +588,7 @@ void ThumbnailView::setThumbnail(const KFileItem &item, const QPixmap &pixmap, c
     Thumbnail &thumbnail = it.value();
     thumbnail.mGroupPix = pixmap;
     thumbnail.mAdjustedPix = QPixmap();
-    int largeGroupSize = ThumbnailGroup::pixelSize(ThumbnailGroup::Large2x);
+    int largeGroupSize = ThumbnailGroup::pixelSize(ThumbnailGroup::XLarge);
     thumbnail.mFullSize = size.isValid() ? size : QSize(largeGroupSize, largeGroupSize);
     thumbnail.mRealFullSize = size;
     thumbnail.mWaitingForThumbnail = false;
@@ -634,7 +634,7 @@ QPixmap ThumbnailView::thumbnailForIndex(const QModelIndex &index, QSize *fullSi
         if (fullSize) {
             *fullSize = QSize();
         }
-        return QPixmap();
+        return {};
     }
     QUrl url = item.url();
 
@@ -726,7 +726,7 @@ void ThumbnailView::startDrag(Qt::DropActions)
         selectedFiles << fileItemForIndex(index);
     }
 
-    auto *drag = new QDrag(this);
+    auto drag = new QDrag(this);
     drag->setMimeData(MimeTypeUtils::selectionMimeData(selectedFiles, MimeTypeUtils::DropTarget));
     d->initDragPixmap(drag, indexes);
     drag->exec(Qt::MoveAction | Qt::CopyAction | Qt::LinkAction, Qt::CopyAction);
